@@ -265,6 +265,35 @@ find_formula.maxLik <- find_formula.default
 find_formula.maxim <- find_formula.default
 
 
+#' @export
+find_formula.svy_vglm <- function(x, ...) {
+  find_formula(x$fit)
+}
+
+
+#' @export
+find_formula.mjoint <- function(x, ...) {
+  s <- summary(x)
+
+  f.cond <- s$formLongFixed
+  if (length(s$formLongFixed) == 1) {
+    names(f.cond) <- "conditional"
+  } else {
+    names(f.cond) <- paste0("conditional", 1:length(f.cond))
+  }
+
+  f.rand <- s$formLongRandom
+  if (length(s$formLongRandom) == 1) {
+    names(f.rand) <- "random"
+  } else {
+    names(f.rand) <- paste0("random", 1:length(f.rand))
+  }
+
+  f <- c(f.cond, f.rand, list(survival = s$formSurv))
+  .find_formula_return(f)
+}
+
+
 #' @export
 find_formula.btergm <- function(x, ...) {
   f <- list(conditional = x@formula)
@@ -309,6 +338,13 @@ find_formula.glht <- function(x, ...) {
 }
 
 
+#' @export
+find_formula.joint <- function(x, ...) {
+  f <- stats::formula(x)
+  .find_formula_return(list(conditional = f$lformula, survival = f$sformula))
+}
+
+
 #' @export
 find_formula.betareg <- function(x, ...) {
   f <- stats::formula(x)
@@ -575,24 +611,24 @@ find_formula.plm <- function(x, ...) {
 #' @export
 find_formula.felm <- function(x, ...) {
   f <- .safe_deparse(stats::formula(x))
-  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE))
+  f_parts <- .trim(unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE)))
 
-  f.cond <- .trim(f_parts[1])
+  f.cond <- f_parts[1]
 
   if (length(f_parts) > 1) {
-    f.rand <- paste0("~", .trim(f_parts[2]))
+    f.rand <- paste0("~", f_parts[2])
   } else {
     f.rand <- NULL
   }
 
   if (length(f_parts) > 2) {
-    f.instr <- paste0("~", .trim(f_parts[3]))
+    f.instr <- paste0("~", f_parts[3])
   } else {
     f.instr <- NULL
   }
 
   if (length(f_parts) > 3) {
-    f.clus <- paste0("~", .trim(f_parts[4]))
+    f.clus <- paste0("~", f_parts[4])
   } else {
     f.clus <- NULL
   }
@@ -608,6 +644,43 @@ find_formula.felm <- function(x, ...) {
 
 
 
+#' @export
+find_formula.mhurdle <- function(x, ...) {
+  f <- .safe_deparse(stats::formula(x)[[3]])
+  f_parts <- .trim(unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE)))
+
+  f.zi <- paste0("~", f_parts[1])
+
+  if (length(f_parts) > 1) {
+    f.cond <- paste0(.safe_deparse(stats::formula(x)[[2]]), "~", f_parts[2])
+  } else {
+    f.cond <- NULL
+  }
+
+  if (length(f_parts) > 2) {
+    f.ip <- paste0("~", f_parts[3])
+  } else {
+    f.ip <- NULL
+  }
+
+  # remove "empty" parts
+  if (f.zi == "~0") {
+    f.zi <- NULL
+  }
+  if (f.ip == "~0") {
+    f.ip <- NULL
+  }
+
+  f <- .compact_list(list(
+    conditional = stats::as.formula(f.cond),
+    zero_inflated = stats::as.formula(f.zi),
+    infrequent_purchase = stats::as.formula(f.ip)
+  ))
+  .find_formula_return(f)
+}
+
+
+
 #' @export
 find_formula.feglm <- function(x, ...) {
   f <- .safe_deparse(stats::formula(x))
@@ -1322,7 +1395,7 @@ find_formula.BFBayesFactor <- function(x, ...) {
 
 #' @export
 find_formula.model_fit <- function(x, ...) {
-  find_formula(x$fit)
+  find_formula(x$fit, ...)
 }
 
 
