@@ -8,6 +8,7 @@
 #'    the name of the response matches the notation in formula, and would for
 #'    instance also contain patterns like \code{"cbind(...)"}. Else, the original
 #'    variable names from the matrix-column are returned. See 'Examples'.
+#' @param ... Currently not used.
 #'
 #' @return The name(s) of the response variable(s) from \code{x} as character
 #'   vector, or \code{NULL} if response variable could not be found.
@@ -22,18 +23,22 @@
 #'   find_response(m, combine = FALSE)
 #' }
 #' @export
-find_response <- function(x, combine = TRUE) {
+find_response <- function(x, combine = TRUE, ...) {
+  UseMethod("find_response")
+}
+
+
+#' @export
+find_response.default <- function(x, combine = TRUE, ...) {
   f <- find_formula(x)
 
   if (is.null(f)) {
     return(NULL)
   }
 
-  # this is for multivariate response models, where
-  # we have a list of formulas
-  if (inherits(x, "mediate")) {
-    resp <- c(.safe_deparse(f$mediator$conditional[[2L]]), .safe_deparse(f$outcome$conditional[[2L]]))
-  } else if (is_multivariate(f)) {
+  # this is for multivariate response models,
+  # where we have a list of formulas
+  if (is_multivariate(f)) {
     resp <- unlist(lapply(f, function(i) .safe_deparse(i$conditional[[2L]])))
   } else {
     resp <- .safe_deparse(f$conditional[[2L]])
@@ -43,6 +48,75 @@ find_response <- function(x, combine = TRUE) {
 }
 
 
+#' @export
+find_response.model_fit <- function(x, combine = TRUE, ...) {
+  find_response(x$fit, combine = combine, ...)
+}
+
+
+#' @export
+find_response.mediate <- function(x, combine = TRUE, ...) {
+  f <- find_formula(x)
+
+  if (is.null(f)) {
+    return(NULL)
+  }
+
+  resp <- c(.safe_deparse(f$mediator$conditional[[2L]]), .safe_deparse(f$outcome$conditional[[2L]]))
+  check_cbind(resp, combine, model = x)
+}
+
+
+#' @export
+find_response.mjoint <- function(x, combine = TRUE, component = c("conditional", "survival", "all"), ...) {
+  component <- match.arg(component)
+  f <- find_formula(x)
+
+  if (is.null(f)) {
+    return(NULL)
+  }
+
+  conditional <- unlist(lapply(f[grepl("^conditional", names(f))], function(i) .safe_deparse(i[[2L]])))
+  survial <- .safe_deparse(f$survival[[2L]])
+
+  resp <- switch(component,
+                 "conditional" = conditional,
+                 "survial" = survial,
+                 "all" = c(conditional, survial))
+
+  unlist(lapply(resp, check_cbind, combine = combine, model = x))
+}
+
+
+#' @export
+find_response.joint <- function(x, combine = TRUE, component = c("conditional", "survival", "all"), ...) {
+  component <- match.arg(component)
+  f <- find_formula(x)
+
+  if (is.null(f)) {
+    return(NULL)
+  }
+
+  conditional <- .safe_deparse(f$conditional[[2L]])
+  survial <- .safe_deparse(f$survival[[2L]])
+
+  resp <- switch(component,
+                 "conditional" = conditional,
+                 "survial" = survial,
+                 "all" = c(conditional, survial))
+
+  unlist(lapply(resp, check_cbind, combine = combine, model = x))
+}
+
+
+
+
+
+
+
+# utils ---------------------
+
+
 # should not be called for brms-models!
 check_cbind <- function(resp, combine, model) {
   if (!combine && inherits(model, "DirichletRegModel")) {
