@@ -92,6 +92,11 @@ get_data.summary.lm <- function(x, ...) {
 }
 
 
+#' @export
+get_data.model_fit <- function(x, verbose = TRUE, ...) {
+  get_data(x$fit, verbose = verbose, ...)
+}
+
 
 
 
@@ -99,6 +104,29 @@ get_data.summary.lm <- function(x, ...) {
 # classical and survival models -----------------------------------------------
 
 
+#' @export
+get_data.mjoint <- function(x, verbose = TRUE, ...) {
+  mf <- tryCatch(
+    {
+      dat <- x$data[[1]]
+      data_columns <- intersect(
+        colnames(dat),
+        unique(c(
+          find_response(x, combine = FALSE, component = "all"),
+          find_variables(x, flatten = TRUE)
+        ))
+      )
+      dat[, data_columns, drop = FALSE]
+    },
+    error = function(x) {
+      NULL
+    }
+  )
+
+  .prepare_get_data(x, stats::na.omit(mf), verbose = verbose)
+}
+
+
 #' @rdname get_data
 #' @export
 get_data.gee <- function(x, effects = c("all", "fixed", "random"), verbose = TRUE, ...) {
@@ -972,6 +1000,13 @@ get_data.negbinmfx <- get_data.betamfx
 # other models ------------------------------------------------------
 
 
+#' @export
+get_data.svy_vglm <- function(x, verbose = TRUE, ...) {
+  mf <- x$design$variables[find_variables(x, flatten = TRUE)]
+  .prepare_get_data(x, mf, verbose = verbose)
+}
+
+
 #' @export
 get_data.mediate <- function(x, ...) {
   d1 <- get_data(x$model.m)
