@@ -37,88 +37,35 @@ supported_models <- function() {
 
 .supported_models_list <- function() {
   c(
-    "aareg",
-    "afex_aov",
-    "aov",
-    "aovlist",
-    "Anova.mlm",
-    "Arima",
-    "averaging",
-    "bamlss",
-    "bamlss.frame",
-    "bayesx",
-    "bayesQR",
-    "BBmm",
-    "BBreg",
-    "bcplm",
-    "betamfx",
-    "betaor",
-    "betareg",
-    "BFBayesFactor",
-    "BGGM",
-    "bife",
-    "biglm",
-    "bigglm",
-    "blavaan",
-    "blrm",
-    "bracl",
-    "brglm",
-    "brmsfit",
-    "brmultinom",
+    # a ----------------------------
+    "aareg", "afex_aov", "aov", "aovlist", "Anova.mlm", "Arima", "averaging",
+
+    # b ----------------------------
+    "bamlss", "bamlss.frame", "bayesx", "bayesQR", "BBmm", "BBreg", "bcplm",
+    "betamfx", "betaor", "betareg", "BFBayesFactor", "BGGM", "bife", "biglm",
+    "bigglm", "blavaan", "blrm", "bracl", "brglm", "brmsfit", "brmultinom",
     "btergm",
-    "censReg",
-    "cgam",
-    "cgamm",
-    "cglm",
-    "clm",
-    "clm2",
-    "clmm",
-    "clmm2",
-    "clogit",
-    "coeftest",
-    "complmrob",
-    "coxme",
-    "coxph",
-    "coxph.penal",
-    "coxr",
-    "cpglm",
-    "cpglmm",
-    "crch",
-    "crq",
-    "crqs",
-    "crr",
+
+    # c ----------------------------
+    "censReg", "cgam", "cgamm", "cglm", "clm", "clm2", "clmm", "clmm2",
+    "clogit", "coeftest", "complmrob", "coxme", "coxph", "coxph.penal", "coxr",
+    "cpglm", "cpglmm", "crch", "crq", "crqs", "crr",
+
+    # d ----------------------------
     "DirichletRegModel",
-    "eglm",
-    "elm",
-    "ergm",
-    "feis",
-    "felm",
-    "feglm",
-    "fitdistr",
-    "fixest",
-    "flexsurvreg",
-    "gam",
-    "Gam",
-    "gamlss",
-    "gamm",
-    "gamm4",
-    "garch",
-    "gbm",
-    "gee",
-    "geeglm",
-    "glht",
-    "glimML",
-    "glmm",
-    "glm",
-    "Glm",
-    "glmmadmb",
-    "glmmPQL",
-    "glmmTMB",
-    "glmrob",
-    "glmRob",
-    "glmx",
-    "gls",
-    "gmnl",
+
+    # e ----------------------------
+    "eglm", "elm", "ergm",
+
+    # f ----------------------------
+    "feis", "felm", "feglm", "fitdistr",  "fixest", "flexsurvreg",
+
+    # g ----------------------------
+    "gam", "Gam", "gamlss", "gamm", "gamm4", "garch", "gbm", "gee", "geeglm",
+    "glht", "glimML", "glmm", "glm", "Glm", "glmmadmb", "glmmPQL", "glmmTMB",
+    "glmrob", "glmRob", "glmx", "gls", "gmnl",
+
+    # h ----------------------------
     "HLfit",
     "htest",
     "hurdle",
@@ -157,6 +104,8 @@ supported_models <- function() {
     "mixed",
     "mixor",
     "MixMod",
+    "mhurdle",
+    "mjoint",
     "mle",
     "mle2",
     "mlm",
@@ -167,10 +116,12 @@ supported_models <- function() {
     "meta_random",
     "mlogit",
     "mmlogit",
+    "model_fit",
     "multinom",
     "negbinmfx",
     "negbinirr",
     "ols",
+    "orm",
     "poissonmfx",
     "poissonirr",
     "plm",
@@ -189,6 +140,7 @@ supported_models <- function() {
     "rq",
     "rqs",
     "rqss",
+    "sarlm",
     "scam",
     "sem",
     "speedlm",
@@ -198,6 +150,7 @@ supported_models <- function() {
     "summary.lm",
     "survfit",
     "survreg",
+    "svy_vglm",
     "svyglm",
     "svyolr",
     "tobit",
