@@ -357,6 +357,9 @@ link_function.poissonirr <- link_function.logitmfx
 #' @export
 link_function.logitor <- link_function.logitmfx
 
+#' @export
+link_function.model_fit <- link_function.logitmfx
+
 
 
 
@@ -628,6 +631,12 @@ link_function.vglm <- function(x, ...) {
 }
 
 
+#' @export
+link_function.svy_vglm <- function(x, ...) {
+  link_function(x$fit)
+}
+
+
 #' @export
 link_function.polr <- function(x, ...) {
   link <- switch(x$method,
