@@ -670,6 +670,14 @@ link_inverse.vgam <- function(x, ...) {
 #' @export
 link_inverse.vglm <- link_inverse.vgam
 
+#' @export
+link_inverse.svy_vglm <- function(x, ...) {
+  link_inverse(x$fit)
+}
+
+#' @export
+link_inverse.model_fit <- link_inverse.svy_vglm
+
 
 #' @export
 link_inverse.gam <- function(x, ...) {
