@@ -25,7 +25,6 @@ n_obs <- function(x, ...) {
 
 #' @export
 n_obs.default <- function(x, ...) {
-
   is_binomial <- tryCatch(
     {
       fam <- stats::family(x)
@@ -96,6 +95,16 @@ n_obs.svyolr <- function(x, weighted = FALSE, ...) {
 }
 
 
+#' @export
+n_obs.svy_vglm <- function(x, ...) {
+  n_obs(x$fit)
+}
+
+
+#' @export
+n_obs.model_fit <- n_obs.svy_vglm
+
+
 #' @export
 n_obs.gam <- function(x, ...) {
   if (!is.null(dim(x$y))) {
@@ -109,7 +118,7 @@ n_obs.gam <- function(x, ...) {
 n_obs.gamm <- function(x, ...) {
   if (.obj_has_name(x, "gam")) {
     n_obs(x$gam, ...)
-  } else{
+  } else {
     stop("Cannot find n_obs for this object. Please an open an issue!")
   }
 }
@@ -124,6 +133,18 @@ n_obs.lavaan <- function(x, ...) {
 }
 
 
+#' @export
+n_obs.mjoint <- function(x, ...) {
+  nrow(x$data[[1]])
+}
+
+
+#' @export
+n_obs.joint <- function(x, ...) {
+  nrow(x$data$longitudinal)
+}
+
+
 #' @export
 n_obs.merModList <- function(x, ...) {
   stats::nobs(x[[1]])
@@ -243,6 +264,9 @@ n_obs.biglm <- function(x, ...) {
 #' @export
 n_obs.bigglm <- n_obs.biglm
 
+#' @export
+n_obs.eglm <- n_obs.biglm
+
 #' @export
 n_obs.rqss <- n_obs.biglm
 
@@ -417,6 +441,13 @@ n_obs.survfit <- function(x, ...) {
 
 
 
+#' @export
+n_obs.mhurdle <- function(x, ...) {
+  nrow(x$model)
+}
+
+
+
 #' @export
 n_obs.survreg <- function(x, ...) {
   length(x$linear.predictors)
