@@ -2,9 +2,10 @@
 #' @name print_parameters
 #'
 #' @description This function takes a data frame, typically a data frame with
-#' information on summaries of model parameters like \code{\link[bayestestR]{hdi}}
-#' or \code{\link[bayestestR]{equivalence_test}}, as input and splits this information
-#' into several parts, depending on the model. See details below.
+#' information on summaries of model parameters like \code{\link[bayestestR]{describe_posterior}},
+#' \code{\link[bayestestR]{hdi}} or \code{\link[parameters]{model_parameters}},
+#' as input and splits this information into several parts, depending on the
+#' model. See details below.
 #'
 #' @param x A fitted model, or a data frame returned by \code{\link{clean_parameters}}.
 #' @param ... One or more objects (data frames), which contain information about
@@ -21,11 +22,26 @@
 #'   assumed use for output is basic printing. If \code{"markdown"}, markdown-format
 #'   is assumed. This only affects the style of title- and table-caption attributes,
 #'   which are used in \code{\link{export_table}}.
+#' @param parameter_column String, name of the column that contains the
+#'   parameter names. Usually, for data frames returned by functions the
+#'   easystats-packages, this will be \code{"Parameter"}.
 #' @param keep_parameter_column Logical, if \code{TRUE}, the data frames in the
 #'   returned list have both a \code{"Cleaned_Parameter"} and \code{"Parameter"}
 #'   column. If \code{FALSE}, the (unformatted) \code{"Parameter"} is removed,
 #'   and the column with cleaned parameter names (\code{"Cleaned_Parameter"}) is
 #'   renamed into \code{"Parameter"}.
+#' @param remove_empty_column Logical, if \code{TRUE}, columns with completely
+#'   empty character values will be removed.
+#' @param titles,subtitles By default, the names of the model components (like
+#'   fixed or random effects, count or zero-inflated model part) are added as
+#'   attributes \code{"table_title"} and \code{"table_subtitle"} to each list
+#'   element returned by \code{print_parameters()}. These attributes are then
+#'   extracted and used as table (sub) titles in \code{\link{export_table}}.
+#'   Use \code{titles} and \code{subtitles} to override the default attribute
+#'   values for \code{"table_title"} and \code{"table_subtitle"}. \code{titles}
+#'   and \code{subtitles} may be any length from 1 to same length as returned
+#'   list elements. If \code{titles} and \code{subtitles} are shorter than
+#'   existing elements, only the first default attributes are overwritten.
 #'
 #' @return A data frame or a list of data frames (if \code{split_by} is not \code{NULL}).
 #' If a list is returned, the element names reflect the model components where the
@@ -45,14 +61,16 @@
 #' Then, \code{...} take one or more data frames that also contain information
 #' about parameters from the same model, but also have additional information
 #' provided by other methods. For instance, a data frame in \code{...} might
-#' be the result of \code{\link[bayestestR]{hdi}}, where we
-#' have a) a \code{Parameters} column and b) columns with the HDI values.
+#' be the result of, for instance, \code{\link[bayestestR]{describe_posterior}},
+#' or \code{\link[parameters]{model_parameters}}, where we have a) a
+#' \code{Parameter} column and b) columns with other parameter values (like
+#' CI, HDI, test statistic, etc.).
 #' \cr \cr
 #' Now we have a data frame with model parameters and information about the
 #' association to the different model components, a data frame with model
 #' parameters, and some summary statistics. \code{print_parameters()}
-#' then merges these data frames, so the statistic of interest (in our example:
-#' the HDI) is also associated with the different model components. The data
+#' then merges these data frames, so the parameters or statistics of interest
+#' are also associated with the different model components. The data
 #' frame is split into a list, so for a clear printing. Users can loop over this
 #' list and print each component for a better overview. Further, parameter
 #' names are "cleaned", if necessary, also for a cleaner print. See also 'Examples'.
@@ -63,8 +81,8 @@
 #' model <- download_model("brms_zi_2")
 #' x <- hdi(model, effects = "all", component = "all")
 #'
-#' # hdi() returns a data frame; here we use only the informaton on
-#' # parameter names and HDI values
+#' # hdi() returns a data frame; here we use only the
+#' # information on parameter names and HDI values
 #' tmp <- as.data.frame(x)[, 1:4]
 #' tmp
 #'
@@ -78,10 +96,17 @@
 #' # different model components.
 #' x
 #' }
-#'
 #' @importFrom stats na.omit
 #' @export
-print_parameters <- function(x, ..., split_by = c("Effects", "Component", "Group", "Response"), format = "text", keep_parameter_column = TRUE) {
+print_parameters <- function(x,
+                             ...,
+                             split_by = c("Effects", "Component", "Group", "Response"),
+                             format = "text",
+                             parameter_column = "Parameter",
+                             keep_parameter_column = TRUE,
+                             remove_empty_column = FALSE,
+                             titles = NULL,
+                             subtitles = NULL) {
   obj <- list(...)
 
   # save attributes of original object
@@ -98,11 +123,14 @@ print_parameters <- function(x, ..., split_by = c("Effects", "Component", "Group
   } else {
     x
   }
-  cn1 <- colnames(cp)
 
   # merge all objects together
   obj <- Reduce(
     function(x, y) {
+      # check for valid column name
+      if (parameter_column != "Parameter" && parameter_column %in% colnames(y) && !"Parameter" %in% colnames(y)) {
+        colnames(y)[colnames(y) == parameter_column] <- "Parameter"
+      }
       merge_by <- unique(c("Parameter", intersect(colnames(y), intersect(c("Effects", "Component", "Group", "Response"), colnames(x)))))
       merge(x, y, all.x = FALSE, by = merge_by, sort = FALSE)
     },
@@ -151,8 +179,7 @@ print_parameters <- function(x, ..., split_by = c("Effects", "Component", "Group
 
       # Rename "fixed", "random" etc. into proper titles. Here we have the
       # "Main title" of a subcomponent (like "Random effects")
-      if (parts[j] %in% c("fixed", "random") ||
-        (has_zeroinf && parts[j] %in% c("conditional", "zero_inflated"))) {
+      if (parts[j] %in% c("fixed", "random") || (has_zeroinf && parts[j] %in% c("conditional", "zero_inflated"))) {
         tmp <- switch(parts[j],
           "fixed" = "Fixed effects",
           "random" = "Random effects",
@@ -174,9 +201,17 @@ print_parameters <- function(x, ..., split_by = c("Effects", "Component", "Group
 
     .effects <- unique(element$Effects)
     .component <- unique(element$Component)
+    .group <- unique(element$Group)
 
-    # we don't need "Effects" and "Random" column any more
-    keep <- setdiff(colnames(element), c("Effects", "Component", "Cleaned_Parameter"))
+    # we don't need "Effects" and "Component" column any more, and probably
+    # also no longer the "Group" column
+    columns_to_remove <- c("Effects", "Component", "Cleaned_Parameter")
+    if (.n_unique(.group) == 1) {
+      columns_to_remove <- c(columns_to_remove, "Group")
+    } else {
+      .group <- NULL
+    }
+    keep <- setdiff(colnames(element), columns_to_remove)
     element <- element[, c("Cleaned_Parameter", keep)]
 
     # if we had a pretty_names attributes in the original object,
@@ -192,6 +227,15 @@ print_parameters <- function(x, ..., split_by = c("Effects", "Component", "Group
       colnames(element)[colnames(element) == "Cleaned_Parameter"] <- "Parameter"
     }
 
+    # remove empty columns
+    if (isTRUE(remove_empty_column)) {
+      for (j in colnames(element)) {
+        if (all(is.na(element[[j]])) || (is.character(element[[j]]) && all(element[[j]] == ""))) {
+          element[[j]] <- NULL
+        }
+      }
+    }
+
     # for sub-table titles
     if (is.null(format) || format == "text") {
       title_prefix <- "# "
@@ -199,17 +243,39 @@ print_parameters <- function(x, ..., split_by = c("Effects", "Component", "Group
       title_prefix <- ""
     }
 
+    title1 <- .capitalize(title1)
+    title2 <- .capitalize(title2)
+
     # add attributes
     attr(element, "main_title") <- .trim(title1)
-    attr(element, "table_caption") <- c(paste0(title_prefix, .trim(title1)), "blue")
     attr(element, "sub_title") <- .trim(title2)
-    attr(element, "table_subtitle") <- c(.trim(title2), "red")
+    if (is.null(format) || format == "text") {
+      attr(element, "table_caption") <- c(paste0(title_prefix, .trim(title1)), "blue")
+      attr(element, "table_subtitle") <- c(.trim(title2), "blue")
+    } else {
+      attr(element, "table_caption") <- .trim(title1)
+      attr(element, "table_subtitle") <- .trim(title2)
+    }
     attr(element, "Effects") <- .effects
     attr(element, "Component") <- .component
+    attr(element, "Group") <- .group
 
     element
   })
 
+  # override titles?
+  if (!is.null(titles) && length(titles) <= length(out)) {
+    for (i in 1:length(titles)) {
+      attr(out[[i]], "table_caption") <- c(titles[i], "blue")
+    }
+  }
+
+  if (!is.null(subtitles) && length(subtitles) <= length(out)) {
+    for (i in 1:length(subtitles)) {
+      attr(out[[i]], "table_subtitle") <- c(subtitles[i], "blue")
+    }
+  }
+
   att$pretty_names <- NULL
   attr(out, "additional_attributes") <- att
   names(out) <- list_names
